@@ -46,7 +46,7 @@ void printStr(const wchar_t *str2print)
 
 wstring commafyInt(size_t n)
 {
-	generic_stringstream ss;
+	std::basic_stringstream<wchar_t> ss;
 	ss.imbue(std::locale(""));
 	ss << n;
 	return ss.str();
@@ -54,7 +54,7 @@ wstring commafyInt(size_t n)
 
 std::string getFileContent(const wchar_t *file2read)
 {
-	if (!::PathFileExists(file2read))
+	if (!doesFileExist(file2read))
 		return "";
 
 	const size_t blockSize = 1024;
@@ -68,7 +68,7 @@ std::string getFileContent(const wchar_t *file2read)
 	do
 	{
 		lenFile = fread(data, 1, blockSize, fp);
-		if (lenFile <= 0) break;
+		if (lenFile == 0) break;
 		wholeFileContent.append(data, lenFile);
 	}
 	while (lenFile > 0);
@@ -94,11 +94,11 @@ char getDriveLetter()
 wstring relativeFilePathToFullFilePath(const wchar_t *relativeFilePath)
 {
 	wstring fullFilePathName;
-	wchar_t fullFileName[MAX_PATH];
 	BOOL isRelative = ::PathIsRelative(relativeFilePath);
 
 	if (isRelative)
 	{
+		wchar_t fullFileName[MAX_PATH];
 		::GetFullPathName(relativeFilePath, MAX_PATH, fullFileName, NULL);
 		fullFilePathName += fullFileName;
 	}
@@ -953,7 +953,7 @@ bool matchInExcludeDirList(const wchar_t* dirName, const std::vector<wstring>& p
 	return false;
 }
 
-bool allPatternsAreExclusion(const std::vector<wstring> patterns)
+bool allPatternsAreExclusion(const std::vector<wstring>& patterns)
 {
 	bool oneInclusionPatternFound = false;
 	for (size_t i = 0, len = patterns.size(); i < len; ++i)
@@ -1096,8 +1096,6 @@ bool isCertificateValidated(const wstring & fullFilePath, const wstring & subjec
 	CERT_INFO CertInfo{};
 	LPTSTR szName = NULL;
 
-	wstring subjectName;
-
 	try {
 		// Get message handle and store handle from the signed file.
 		result = CryptQueryObject(CERT_QUERY_OBJECT_FILE,
@@ -1182,7 +1180,7 @@ bool isCertificateValidated(const wstring & fullFilePath, const wstring & subjec
 		}
 
 		// check Subject name.
-		subjectName = szName;
+		wstring subjectName = szName;
 		if (subjectName != subjectName2check)
 		{
 			throw wstring(L"Certificate checking error: the certificate is not matched.");
@@ -1217,7 +1215,7 @@ bool isAssoCommandExisting(LPCTSTR FullPathName)
 {
 	bool isAssoCommandExisting = false;
 
-	bool isFileExisting = PathFileExists(FullPathName) != FALSE;
+	bool isFileExisting = doesFileExist(FullPathName);
 
 	if (isFileExisting)
 	{
@@ -1462,10 +1460,11 @@ HFONT createFont(const wchar_t* fontName, int fontSize, bool isBold, HWND hDestP
 
 bool removeReadOnlyFlagFromFileAttributes(const wchar_t* fileFullPath)
 {
-	if (!PathFileExists(fileFullPath))
+	DWORD dwFileAttribs = ::GetFileAttributes(fileFullPath);
+
+	if (dwFileAttribs == INVALID_FILE_ATTRIBUTES || (dwFileAttribs & FILE_ATTRIBUTE_DIRECTORY))
 		return false;
 
-	DWORD dwFileAttribs = ::GetFileAttributes(fileFullPath);
 	dwFileAttribs &= ~FILE_ATTRIBUTE_READONLY;
 	return (::SetFileAttributes(fileFullPath, dwFileAttribs) != FALSE);
 }
@@ -1637,29 +1636,29 @@ Version::Version(const wstring& versionStr)
 
 void Version::setVersionFrom(const wstring& filePath)
 {
-	if (!filePath.empty() && ::PathFileExists(filePath.c_str()))
+	if (filePath.empty() || !doesFileExist(filePath.c_str()))
+		return;
+
+	DWORD uselessArg = 0; // this variable is for passing the ignored argument to the functions
+	DWORD bufferSize = ::GetFileVersionInfoSize(filePath.c_str(), &uselessArg);
+
+	if (bufferSize <= 0)
+		return;
+
+	unsigned char* buffer = new unsigned char[bufferSize];
+	::GetFileVersionInfo(filePath.c_str(), 0, bufferSize, buffer);
+
+	VS_FIXEDFILEINFO* lpFileInfo = nullptr;
+	UINT cbFileInfo = 0;
+	VerQueryValue(buffer, L"\\", reinterpret_cast<LPVOID*>(&lpFileInfo), &cbFileInfo);
+	if (cbFileInfo)
 	{
-		DWORD uselessArg = 0; // this variable is for passing the ignored argument to the functions
-		DWORD bufferSize = ::GetFileVersionInfoSize(filePath.c_str(), &uselessArg);
-
-		if (bufferSize <= 0)
-			return;
-
-		unsigned char* buffer = new unsigned char[bufferSize];
-		::GetFileVersionInfo(filePath.c_str(), 0, bufferSize, buffer);
-
-		VS_FIXEDFILEINFO* lpFileInfo = nullptr;
-		UINT cbFileInfo = 0;
-		VerQueryValue(buffer, L"\\", reinterpret_cast<LPVOID*>(&lpFileInfo), &cbFileInfo);
-		if (cbFileInfo)
-		{
-			_major = (lpFileInfo->dwFileVersionMS & 0xFFFF0000) >> 16;
-			_minor = lpFileInfo->dwFileVersionMS & 0x0000FFFF;
-			_patch = (lpFileInfo->dwFileVersionLS & 0xFFFF0000) >> 16;
-			_build = lpFileInfo->dwFileVersionLS & 0x0000FFFF;
-		}
-		delete[] buffer;
+		_major = (lpFileInfo->dwFileVersionMS & 0xFFFF0000) >> 16;
+		_minor = lpFileInfo->dwFileVersionMS & 0x0000FFFF;
+		_patch = (lpFileInfo->dwFileVersionLS & 0xFFFF0000) >> 16;
+		_build = lpFileInfo->dwFileVersionLS & 0x0000FFFF;
 	}
+	delete[] buffer;
 }
 
 wstring Version::toString()
@@ -1764,3 +1763,21 @@ bool Version::isCompatibleTo(const Version& from, const Version& to) const
 
 	return false;
 }
+
+bool doesFileExist(const wchar_t* filePath)
+{
+	DWORD dwAttrib = ::GetFileAttributesW(filePath);
+	return (dwAttrib != INVALID_FILE_ATTRIBUTES && !(dwAttrib & FILE_ATTRIBUTE_DIRECTORY));
+}
+
+bool doesDirectoryExist(const wchar_t* dirPath)
+{
+	DWORD dwAttrib = ::GetFileAttributesW(dirPath);
+	return (dwAttrib != INVALID_FILE_ATTRIBUTES && (dwAttrib & FILE_ATTRIBUTE_DIRECTORY));
+}
+
+bool doesPathExist(const wchar_t* path)
+{
+	DWORD dwAttrib = ::GetFileAttributesW(path);
+	return (dwAttrib != INVALID_FILE_ATTRIBUTES);
+}
