@@ -13,6 +13,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 #pragma once
 #include <vector>
 #include <string>
@@ -24,6 +25,8 @@
 #include <algorithm>
 #include <tchar.h>
 
+#pragma deprecated(PathFileExists) // Use doesFileExist, doesDirectoryExist or doesPathExist (for file or directory) instead.
+
 
 const bool dirUp = true;
 const bool dirDown = false;
@@ -46,8 +49,6 @@ const bool dirDown = false;
 
 #define NPP_INTERNAL_FUCTION_STR L"Notepad++::InternalFunction"
 
-typedef std::basic_string<wchar_t> generic_string;
-typedef std::basic_stringstream<wchar_t> generic_stringstream;
 
 std::wstring folderBrowser(HWND parent, const std::wstring & title = L"", int outputCtrlID = 0, const wchar_t *defaultStr = NULL);
 std::wstring getFolderName(HWND parent, const wchar_t *defaultDir = NULL);
@@ -74,7 +75,7 @@ std::wstring relativeFilePathToFullFilePath(const wchar_t *relativeFilePath);
 void writeFileContent(const wchar_t *file2write, const char *content2write);
 bool matchInList(const wchar_t *fileName, const std::vector<std::wstring> & patterns);
 bool matchInExcludeDirList(const wchar_t* dirName, const std::vector<std::wstring>& patterns, size_t level);
-bool allPatternsAreExclusion(const std::vector<std::wstring> patterns);
+bool allPatternsAreExclusion(const std::vector<std::wstring>& patterns);
 
 class WcharMbcsConvertor final
 {
@@ -278,3 +279,7 @@ private:
 	unsigned long _patch = 0;
 	unsigned long _build = 0;
 };
+
+bool doesFileExist(const wchar_t* filePath);
+bool doesDirectoryExist(const wchar_t* dirPath);
+bool doesPathExist(const wchar_t* path);
\ No newline at end of file
