@@ -32,8 +32,8 @@ Win32_IO_File::Win32_IO_File(const wchar_t *fname)
 
 		WIN32_FILE_ATTRIBUTE_DATA attributes_original{};
 		DWORD dispParam = CREATE_ALWAYS;
-		BOOL doesFileExist = ::PathFileExistsW(fname);
-		if (doesFileExist)
+		bool fileExists = doesFileExist(fname);
+		if (fileExists)
 		{
 			// Store the file creation date & attributes for a possible use later...
 			::GetFileAttributesExW(fname, GetFileExInfoStandard, &attributes_original);
@@ -59,7 +59,7 @@ Win32_IO_File::Win32_IO_File(const wchar_t *fname)
 			_hFile = ::CreateFileW(fname, _accessParam, _shareParam, NULL, dispParam, _attribParam, NULL);
 		}
 
-		if (doesFileExist && (dispParam == CREATE_ALWAYS) && (_hFile != INVALID_HANDLE_VALUE))
+		if (fileExists && (dispParam == CREATE_ALWAYS) && (_hFile != INVALID_HANDLE_VALUE))
 		{
 			// restore back the original creation date & attributes
 			::SetFileTime(_hFile, &(attributes_original.ftCreationTime), NULL, NULL);
@@ -254,8 +254,7 @@ bool Win32_IO_File::write(const void *wbuf, size_t buf_size)
 		}
 	}
 
-	if (!_written)
-		_written = true;
+	_written = true;
 
 	return (total_bytes_written == buf_size);
 }
