@@ -655,7 +655,7 @@ private:
 	void clearChangesHistory();
 	void changedHistoryGoTo(int idGoTo);
 
-	HMENU createMenuFromMenu(HMENU hSourceMenu, std::vector<int>& commandIds);
+	HMENU createMenuFromMenu(HMENU hSourceMenu, const std::vector<int>& commandIds);
 	BOOL notifyTBShowMenu(LPNMTOOLBARW lpnmtb, const char* menuPosId);
-	BOOL notifyTBShowMenu(LPNMTOOLBARW lpnmtb, const char* menuPosId, std::vector<int> cmdIDs);
+	BOOL notifyTBShowMenu(LPNMTOOLBARW lpnmtb, const char* menuPosId, const std::vector<int>& cmdIDs);
 };
