@@ -30,6 +30,8 @@
 #include <assert.h>
 #include <tchar.h>
 #include <map>
+#include <array>
+#include <shlwapi.h>
 #include "ILexer.h"
 #include "Lexilla.h"
 #include "DockingCont.h"
@@ -118,6 +120,8 @@ enum urlMode {urlDisable = 0, urlNoUnderLineFg, urlUnderLineFg, urlNoUnderLineBg
               urlMin = urlDisable,
               urlMax = urlUnderLineBg};
 
+enum AutoIndentMode { autoIndent_none = 0, autoIndent_advanced = 1, autoIndent_basic = 2 };
+
 const int LANG_INDEX_INSTR = 0;
 const int LANG_INDEX_INSTR2 = 1;
 const int LANG_INDEX_TYPE = 2;
@@ -127,6 +131,14 @@ const int LANG_INDEX_TYPE4 = 5;
 const int LANG_INDEX_TYPE5 = 6;
 const int LANG_INDEX_TYPE6 = 7;
 const int LANG_INDEX_TYPE7 = 8;
+const int LANG_INDEX_SUBSTYLE1 = 9;
+const int LANG_INDEX_SUBSTYLE2 = 10;
+const int LANG_INDEX_SUBSTYLE3 = 11;
+const int LANG_INDEX_SUBSTYLE4 = 12;
+const int LANG_INDEX_SUBSTYLE5 = 13;
+const int LANG_INDEX_SUBSTYLE6 = 14;
+const int LANG_INDEX_SUBSTYLE7 = 15;
+const int LANG_INDEX_SUBSTYLE8 = 16;
 
 const int COPYDATA_PARAMS = 0;
 //const int COPYDATA_FILENAMESA = 1; // obsolete, no more useful
@@ -817,7 +829,7 @@ struct NppGUI final
 	bool _saveAllConfirm = true;
 	bool _setSaveDlgExtFiltToAllTypes = false;
 	bool _doTaskList = true;
-	bool _maintainIndent = true;
+	AutoIndentMode _maintainIndent = autoIndent_advanced;
 	bool _enableSmartHilite = true;
 
 	bool _smartHiliteCaseSensitive = false;
@@ -1376,6 +1388,26 @@ private:
 	std::wstring _stylesXmlPath;
 };
 
+struct HLSColour
+{
+	WORD _hue = 0;
+	WORD _lightness = 0;
+	WORD _saturation = 0;
+
+	HLSColour() = default;
+	HLSColour(WORD hue, WORD lightness, WORD saturation): _hue(hue), _lightness(lightness), _saturation(saturation) {}
+	HLSColour(COLORREF rgb) { ColorRGBToHLS(rgb, &_hue, &_lightness, &_saturation); }
+
+	void loadFromRGB(COLORREF rgb) { ColorRGBToHLS(rgb, &_hue, &_lightness, &_saturation); }
+	COLORREF toRGB() const { return ColorHLSToRGB(_hue, _lightness, _saturation); }
+
+	COLORREF toRGB4DarkModWithTuning(int lightnessMore, int saturationLess) const { 
+		return ColorHLSToRGB(_hue, 
+			static_cast<WORD>(static_cast<int>(_lightness) + lightnessMore), 
+			static_cast<WORD>(static_cast<int>(_saturation) - saturationLess));
+	}
+	COLORREF toRGB4DarkMod() const { return toRGB4DarkModWithTuning(50, 20); }
+};
 
 struct UdlXmlFileState final {
 	TiXmlDocument* _udlXmlDoc = nullptr;
@@ -1895,6 +1927,11 @@ private:
 
 	std::wstring _loadedSessionFullFilePath;
 
+	std::array<HLSColour, 5> individualTabHuesFor_Dark{ { HLSColour{37, 60, 60}, HLSColour{70, 60, 60}, HLSColour{144, 70, 60}, HLSColour{255, 60, 60}, HLSColour{195, 60, 60} } };
+	std::array<HLSColour, 5> individualTabHues{ { HLSColour{37, 210, 150}, HLSColour{70, 210, 150}, HLSColour{144, 210, 150}, HLSColour{255, 210, 150}, HLSColour{195, 210, 150}} };
+
+	std::array<COLORREF, 3> findDlgStatusMessageColor{ red, blue, darkGreen};
+
 public:
 	void setShortcutDirty() { _isAnyShortcutModified = true; };
 	void setAdminMode(bool isAdmin) { _isAdminMode = isAdmin; }
@@ -2001,6 +2038,15 @@ public:
 	void setTheWarningHasBeenGiven(bool isEnabled) { _theWarningHasBeenGiven = isEnabled; };
 	bool theWarningHasBeenGiven() const { return _theWarningHasBeenGiven; }
 
+
+	void initTabCustomColors();
+	void setIndividualTabColor(COLORREF colour2Set, int colourIndex, bool isDarkMode);
+	COLORREF getIndividualTabColor(int colourIndex, bool isDarkMode, bool saturated);
+
+	void initFindDlgStatusMsgCustomColors();
+	void setFindDlgStatusMsgIndexColor(COLORREF colour2Set, int colourIndex);
+	COLORREF getFindDlgStatusMsgColor(int colourIndex);
+
 private:
 	void getLangKeywordsFromXmlTree();
 	bool getUserParametersFromXmlTree();
