@@ -14,8 +14,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-#ifndef PREFERENCE_RC_H
-#define PREFERENCE_RC_H
+#pragma once
 
 	//#define	PREF_MSG_ISCHECKED_GENERALPAGE (WM_USER + 1) // wParam:checkbox/radiobutton ID in General page. lParam is type of "bool *" to get result
 	#define	PREF_MSG_SETGUITOOLICONSSET (WM_USER + 4) // DM_REPOSITION uses WM_USER + 2
@@ -41,7 +40,7 @@
 	#define	IDC_CHECK_ENABLETABCLOSE (IDD_PREFERENCE_SUB_GENRAL + 12)
 	#define	IDC_CHECK_DBCLICK2CLOSE (IDD_PREFERENCE_SUB_GENRAL + 13)
 	#define	IDC_CHECK_ENABLEDOCSWITCHER (IDD_PREFERENCE_SUB_GENRAL + 14)
-	#define	IDC_CHECK_MAINTAININDENT (IDD_PREFERENCE_SUB_GENRAL + 15)
+	//#define	IDC_CHECK_MAINTAININDENT (IDD_PREFERENCE_SUB_GENRAL + 15)
 	#define	IDC_CHECK_KEEPINSAMEDIR (IDD_PREFERENCE_SUB_GENRAL + 16)
 	#define	IDC_CHECK_STYLEMRU (IDD_PREFERENCE_SUB_GENRAL + 17)
 	#define	IDC_CHECK_TAB_HIDE (IDD_PREFERENCE_SUB_GENRAL + 18)
@@ -488,7 +487,7 @@
 	#define IDD_DROPDOWN_RESET_CYAN        (IDD_PREFERENCE_SUB_DARKMODE + 40)
 	#define IDD_DROPDOWN_RESET_OLIVE       (IDD_PREFERENCE_SUB_DARKMODE + 41)
 
-#define IDD_PREFERENCE_SUB_PERFORMANCE 7140 //(IDD_PREFERENCE_BOX + 1100)
+#define IDD_PREFERENCE_SUB_PERFORMANCE 7140 //(IDD_PREFERENCE_BOX + 1140)
 	#define IDC_GROUPSTATIC_PERFORMANCE_RESTRICTION     (IDD_PREFERENCE_SUB_PERFORMANCE + 1)
 	#define IDD_PERFORMANCE_TIP_QUESTION_BUTTON         (IDD_PREFERENCE_SUB_PERFORMANCE + 2)
 	#define IDC_CHECK_PERFORMANCE_ENABLE                (IDD_PREFERENCE_SUB_PERFORMANCE + 3)
@@ -501,4 +500,9 @@
 	#define IDC_CHECK_PERFORMANCE_DEACTIVATEWORDWRAP    (IDD_PREFERENCE_SUB_PERFORMANCE + 10)
 	#define IDC_CHECK_PERFORMANCE_ALLOWCLICKABLELINK    (IDD_PREFERENCE_SUB_PERFORMANCE + 11)
 	#define	IDC_CHECK_PERFORMANCE_SUPPRESS2GBWARNING	(IDD_PREFERENCE_SUB_PERFORMANCE + 12)
-#endif //PREFERENCE_RC_H
+
+#define IDD_PREFERENCE_SUB_INDENTATION 7160 //(IDD_PREFERENCE_BOX + 1160)
+	#define IDC_GROUPSTATIC_AUTOINDENT                  (IDD_PREFERENCE_SUB_INDENTATION + 1)
+	#define IDC_RADIO_AUTOINDENT_NONE             (IDD_PREFERENCE_SUB_INDENTATION + 2)
+	#define IDC_RADIO_AUTOINDENT_BASIC            (IDD_PREFERENCE_SUB_INDENTATION + 3)
+	#define IDC_RADIO_AUTOINDENT_ADVANCED          (IDD_PREFERENCE_SUB_INDENTATION + 4)
