@@ -47,7 +47,7 @@ public:
 	static void initDpiAPI();
 
 	static int getSystemMetricsForDpi(int nIndex, UINT dpi);
-	int getSystemMetricsForDpi(int nIndex) {
+	int getSystemMetricsForDpi(int nIndex) const {
 		return getSystemMetricsForDpi(nIndex, _dpi);
 	}
 	static DPI_AWARENESS_CONTEXT setThreadDpiAwarenessContext(DPI_AWARENESS_CONTEXT dpiContext);
@@ -107,11 +107,11 @@ public:
 		return scale(x, USER_DEFAULT_SCREEN_DPI, getDpiForWindow(hWnd));
 	}
 
-	int scale(int x) {
+	int scale(int x) const {
 		return scale(x, _dpi);
 	}
 
-	int unscale(int x) {
+	int unscale(int x) const {
 		return unscale(x, _dpi);
 	}
 
@@ -123,7 +123,7 @@ public:
 		return -(scale(pt, getDpiForWindow(hWnd), 72));
 	}
 
-	int scaleFont(int pt) {
+	int scaleFont(int pt) const {
 		return scaleFont(pt, _dpi);
 	}
 
@@ -131,11 +131,10 @@ public:
 	static LOGFONT getDefaultGUIFontForDpi(HWND hWnd, FontType type = FontType::message) {
 		return getDefaultGUIFontForDpi(getDpiForWindow(hWnd), type);
 	}
-	LOGFONT getDefaultGUIFontForDpi(FontType type = FontType::message) {
+	LOGFONT getDefaultGUIFontForDpi(FontType type = FontType::message) const {
 		return getDefaultGUIFontForDpi(_dpi, type);
 	}
 
-	static void sendMessageToChildControls(HWND hwndParent, UINT msg, WPARAM wParam, LPARAM lParam);
 	static void loadIcon(HINSTANCE hinst, const wchar_t* pszName, int cx, int cy, HICON* phico, UINT fuLoad = LR_DEFAULTCOLOR);
 
 private:
